Learn R Programming

SHARK4R (version 1.0.2)

check_chlorophyll_conc: Uses data from national marine monitoring for the last 5 years to identify outliers

Description

[Deprecated] This function is deprecated and has been replaced by check_outliers().

Ranges and IQR (interquantile range) for specific parameters is adapted to each datatype

Usage

check_chlorophyll_conc(data)

Value

tibble of data with outliers

Arguments

data

for tibble be be checked