Learn R Programming

SHARK4R (version 1.0.2)

get_nua_taxa: Retrieve taxa information from Nordic Microalgae

Description

This function retrieves all taxonomic information for algae taxa from the Nordic Microalgae API. It fetches details including scientific names, authorities, ranks, and image URLs (in different sizes: large, medium, original, and small).

Usage

get_nua_taxa(unparsed = FALSE)

Value

When unparsed = FALSE: a tibble containing the following columns:

slug

A unique identifier for the taxon.

scientific_name

The scientific name of the taxon.

authority

The authority associated with the scientific name.

rank

The taxonomic rank of the taxon.

Arguments

unparsed

Logical. If TRUE, complete API response is returned as an unparsed list. Default is FALSE.

See Also

https://nordicmicroalgae.org/ for Nordic Microalgae website.

https://nordicmicroalgae.org/api/ for Nordic Microalgae API documentation.

Examples

Run this code
# \donttest{
  # Retrieve and display taxa data
  taxa_data <- get_nua_taxa(unparsed = FALSE)
  head(taxa_data)
# }

Run the code above in your browser using DataLab