This function is deprecated and has been replaced by
read_shark_deliv().
Uses readxl to read excel files with standardized delivery format
shark_read_deliv(filename, skip = 2, sheet = 2)Data frame of file
path to file to be read
Minimum number of rows to skip before reading anything, be it column names or data. Leading empty rows are automatically skipped, so this is a lower bound. Ignored if range is given. Default is 2.
Sheet to read. Either a string (the name of a sheet), or an integer (the position of the sheet). Ignored if the sheet is specified via range. If neither argument specifies the sheet, defaults to the second sheet.