get_nua_taxa: Retrieve taxa information from Nordic Microalgae
Description
This function retrieves all taxonomic information for algae taxa from the Nordic Microalgae API.
It fetches details including scientific names, authorities, ranks, and image URLs (in different sizes: large, medium, original, and small).
Usage
get_nua_taxa(unparsed = FALSE)
Value
When unparsed = FALSE: a tibble containing the following columns:
slug
A unique identifier for the taxon.
scientific_name
The scientific name of the taxon.
authority
The authority associated with the scientific name.
rank
The taxonomic rank of the taxon.
Arguments
unparsed
Logical. If TRUE, complete API response is returned as an unparsed list. Default is FALSE.