Learn R Programming

SHARK4R (version 1.0.2)

get_toxin_list: Retrieve marine biotoxin data from IOC-UNESCO Toxins Database

Description

This function collects data from the IOC-UNESCO Toxins Database and returns information about toxins.

Usage

get_toxin_list(return_count = FALSE)

Value

If return_count = TRUE, the function returns a numeric value representing the number of toxins in the database. Otherwise, it returns a tibble of toxins with detailed information.

Arguments

return_count

Logical. If TRUE, the function returns the count of toxins available in the database. If FALSE (default), it returns detailed toxin data.

See Also

https://toxins.hais.ioc-unesco.org/ for IOC-UNESCO Toxins Database.

Examples

Run this code
# \donttest{
# Retrieve the full list of toxins
toxin_list <- get_toxin_list()
head(toxin_list)

# Retrieve only the count of toxins
toxin_count <- get_toxin_list(return_count = TRUE)
print(toxin_count)
# }

Run the code above in your browser using DataLab