Learn R Programming

SHARK4R (version 1.0.2)

update_worms_taxonomy: Retrieve and organize WoRMS taxonomy for SHARK Aphia IDs

Description

[Deprecated]

This function was deprecated and replaced by a function with more accurate name. Use add_worms_taxonomy() instead.

This function collects WoRMS (World Register of Marine Species) taxonomy information for a given set of Aphia IDs. The data is organized into a full taxonomic table that can be joined with data downloaded from SHARK.

Usage

update_worms_taxonomy(aphia_id, aphiaid = deprecated())

Value

A tibble containing updated WoRMS taxonomy information.

Arguments

aphia_id

A numeric vector containing Aphia IDs for which WoRMS taxonomy needs to be updated.

aphiaid

[Deprecated] Use aphia_id instead.

See Also

https://marinespecies.org/ for WoRMS website.

get_shark_data, update_dyntaxa_taxonomy, WoRMS API Documentation, https://CRAN.R-project.org/package=worrms

Examples

Run this code
# \donttest{
# Update WoRMS taxonomy for a set of Aphia IDs
updated_taxonomy <- update_worms_taxonomy(c(149619, 149122, 11))
print(updated_taxonomy)
# }

Run the code above in your browser using DataLab