update_worms_taxonomy: Retrieve and organize WoRMS taxonomy for SHARK Aphia IDs
Description
This function was deprecated and replaced by a function with more accurate name. Use add_worms_taxonomy() instead.
This function collects WoRMS (World Register of Marine Species) taxonomy information for a given set of Aphia IDs.
The data is organized into a full taxonomic table that can be joined with data downloaded from SHARK.